==> owncloud-app-gallery-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/gallery/l10n/de.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "Pictures" : "Bilder",
    "No pictures found" : "Keine Bilder gefunden",
    "Upload pictures in the files app to display them here" : "Bilder in die App hochladen, um diese dort anzuzeigen",
    "Nothing in here" : "Hier ist nichts",
    "No media files found in this folder" : "Keine Mediadateien in diesem Ordner gefunden",
    "Aborting preview. Could not find the file" : "Die Vorschau wird abgebrochen. Die Datei konnte nicht gefunden werden",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine ownCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige ownCloud-URL",
    "Gallery view" : "Gallerieansicht",
    "Could not load the description" : "Die Beschreibung konnte nicht geladen werden",
    "Could not load the description: " : "Die Beschreibung konnte nicht geladen werden:",
    "Copyright" : "Urheberrecht",
    "Could not load the copyright notice: " : "Konnte den Urheberrechtshinweis nicht laden:",
    "Copyright notice" : "Urheberrechtshinweis",
    "Link to copyright document" : "Verknüpfung zum Dokument über das Urheberrecht",
    "This application may not work properly on your browser." : "Diese Anwendung wird wahrscheinlich nicht ordnungsgemäß mit deinem Browser funktionieren.",
    "For an improved experience, please install one of the following alternatives" : "Bitte installieren für eine bessere Erfahrung eine der folgenden Alternativen",
    "Your browser is not supported!" : "Dein Browser wird nicht unterstützt!",
    "please install one of the following alternatives" : "Bitte installieren eine der folgenden Alternativen",
    "Configuration error" : "Konfigurationsfehler",
    "Error loading slideshow template" : "Fehler beim Laden der Slideshow-Vorlage",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>" : "<strong>Fehler!</strong> Konnte keine Vorschau dieser Datei erstellen.<br>",
    "Next" : "Weiter",
    "Play" : "Abspielen",
    "Pause" : "Anhalten",
    "Previous" : "Zurück",
    "Close" : "Schließen",
    "Download" : "Herunterladen",
    "Toggle background" : "Hintergrund umschalten",
    "Shared" : "Geteilt",
    "Error" : "Fehler",
    "Error while sharing" : "Fehler beim Teilen",
    "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
    "Error while changing permissions" : "Fehler beim Ändern der Rechte",
    "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Dir und der Gruppe {group} geteilt",
    "Shared with you by {owner}" : "{owner} hat dies mit Dir geteilt",
    "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
    "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
    "Share" : "Teilen",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
    "Share link" : "Link teilen",
    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
    "Link" : "Link",
    "Password protect" : "Passwortschutz",
    "Password" : "Passwort",
    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
    "Allow editing" : "Bearbeitung erlauben",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "Set expiration date" : "Setze ein Ablaufdatum",
    "Expiration" : "Ablaufdatum",
    "Expiration date" : "Ablaufdatum",
    "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuche es noch einmal",
    "Adding user..." : "Benutzer wird hinzugefügt…",
    "group" : "Gruppe",
    "remote" : "Entfernte Freigabe",
    "Resharing is not allowed" : "Weiterverteilen ist nicht erlaubt",
    "Shared in {item} with {user}" : "Für {user} in {item} freigegeben",
    "Unshare" : "Freigabe aufheben",
    "notify by email" : "per E-Mail benachrichtigen",
    "can share" : "kann teilen",
    "can edit" : "kann bearbeiten",
    "access control" : "Zugriffskontrolle",
    "create" : "erstellen",
    "change" : "Ändern",
    "delete" : "löschen",
    "Password protected" : "Durch ein Passwort geschützt",
    "Error unsetting expiration date" : "Fehler beim Entfernen des Ablaufdatums",
    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
    "Sending ..." : "Senden…",
    "Email sent" : "E-Mail wurde verschickt",
    "Warning" : "Warnung",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Bitte überprüfe Dein Passwort und versuche es erneut.",
    "Sort by date" : "Nach Datum ordnen",
    "Sort by name" : "Nach Name ordnen",
    "Album information" : "Albuminformation",
    "File list" : "Dateiliste",
    "Sorry, this file could not be found." : "Entschuldigung, diese Datei konnte nicht gefunden werden.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the wrong file ID was provided" : "Falsche Datei-ID wurde angegeben",
    "the file was removed" : "die Datei wurde entfernt",
    "the file is corrupt" : "die Datei ist beschädigt",
    "the encryption key is missing" : "Der Verschlüsselungsschlüssel fehlt",
    "Here is the error message returned by the server: " : "Hier ist die Fehlermeldung, welche vom Server zurückgegeben wurde:",
    "For more information, please contact your friendly ownCloud administrator." : "Bitte kontaktiere für mehr Informationen deinen freundlichen ownCloud-Administrator.",
    "Sorry, but the server could not fulfill your request." : "Entschuldigung, aber der Server konnte deine Anfrage nicht beantworten.",
    "Possible reasons for the problem:" : "Mögliche Gründe für das Problem:",
    "a conflicting app was installed" : "eine konfliktträchtige App wurde installiert",
    "a required component is missing or was disconnected" : "Eine Komponente, welche vonnöten ist, fehlt oder wurde getrennt",
    "the filesystem is not readable" : "Das Dateisystem ist nicht lesbar",
    "Sorry, this link doesn't seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "the item was removed" : "Das Element wurde entfernt",
    "the link has expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more information, please ask the person who has sent you this link." : "Um nähere Informationen zu erhalten, wende Dich bitte an die Person, die Dir diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Deiner ownCloud hinzufügen",
    "Picture view" : "Bildansicht"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-gallery-9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/gallery/l10n/de.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerie",
    "No pictures found" : "Keine Bilder gefunden",
    "Upload pictures in the files app to display them here" : "Bilder in die App hochladen, um diese dort anzuzeigen",
    "Nothing in here" : "Hier ist nichts",
    "No media files found in this folder" : "Keine Mediadateien in diesem Ordner gefunden",
    "Aborting preview. Could not find the file" : "Die Vorschau wird abgebrochen. Die Datei konnte nicht gefunden werden",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine ownCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige ownCloud-URL",
    "Gallery view" : "Gallerieansicht",
    "Could not load the description" : "Die Beschreibung konnte nicht geladen werden",
    "Could not load the description: " : "Die Beschreibung konnte nicht geladen werden:",
    "Copyright" : "Urheberrecht",
    "Could not load the copyright notice: " : "Konnte den Urheberrechtshinweis nicht laden:",
    "Copyright notice" : "Urheberrechtshinweis",
    "Link to copyright document" : "Verknüpfung zum Dokument über das Urheberrecht",
    "This application may not work properly on your browser." : "Diese Anwendung wird wahrscheinlich nicht ordnungsgemäß mit deinem Browser funktionieren.",
    "For an improved experience, please install one of the following alternatives" : "Bitte eine der folgenden Alternativen installieren",
    "Your browser is not supported!" : "Dein Browser wird nicht unterstützt!",
    "please install one of the following alternatives" : "Bitte eine der folgenden Alternativen installieren",
    "Configuration error" : "Konfigurationsfehler",
    "Error loading slideshow template" : "Fehler beim Laden der Slideshow-Vorlage",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>" : "<strong>Fehler!</strong> Konnte keine Vorschau dieser Datei erstellen.<br>",
    "Next" : "Weiter",
    "Play" : "Abspielen",
    "Pause" : "Anhalten",
    "Previous" : "Zurück",
    "Close" : "Schließen",
    "Download" : "Herunterladen",
    "Toggle background" : "Hintergrund umschalten",
    "Shared" : "Geteilt",
    "Error" : "Fehler",
    "Error while sharing" : "Fehler beim Teilen",
    "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
    "Error while changing permissions" : "Fehler beim Ändern der Rechte",
    "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Dir und der Gruppe {group} geteilt",
    "Shared with you by {owner}" : "{owner} hat dies mit Dir geteilt",
    "Share with users or groups …" : "Mit Benutzern oder Gruppen teilen…",
    "Share with users, groups or remote users …" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
    "Share" : "Teilen",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
    "Share link" : "Link teilen",
    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
    "Link" : "Link",
    "Password protect" : "Passwortschutz",
    "Password" : "Passwort",
    "Choose a password for the public link" : "Wählen Sie ein Passwort für den öffentlichen Link",
    "Allow editing" : "Bearbeitung erlauben",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send" : "Senden",
    "Set expiration date" : "Setze ein Ablaufdatum",
    "Expiration" : "Ablaufdatum",
    "Expiration date" : "Ablaufdatum",
    "An error occured. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuche es noch einmal",
    "Adding user..." : "Benutzer wird hinzugefügt…",
    "group" : "Gruppe",
    "remote" : "Entfernte Freigabe",
    "Resharing is not allowed" : "Weiterverteilen ist nicht erlaubt",
    "Shared in {item} with {user}" : "Für {user} in {item} freigegeben",
    "Unshare" : "Freigabe aufheben",
    "notify by email" : "per E-Mail benachrichtigen",
    "can share" : "kann teilen",
    "can edit" : "kann bearbeiten",
    "access control" : "Zugriffskontrolle",
    "create" : "erstellen",
    "change" : "Ändern",
    "delete" : "löschen",
    "Password protected" : "Durch ein Passwort geschützt",
    "Error unsetting expiration date" : "Fehler beim Entfernen des Ablaufdatums",
    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
    "Sending ..." : "Senden…",
    "Email sent" : "E-Mail wurde verschickt",
    "Warning" : "Warnung",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Bitte überprüfe Dein Passwort und versuche es erneut.",
    "Sort by date" : "Nach Datum ordnen",
    "Sort by name" : "Nach Name ordnen",
    "Album information" : "Albuminformation",
    "File list" : "Dateiliste",
    "Sorry, this file could not be found." : "Entschuldigung, diese Datei konnte nicht gefunden werden.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the wrong file ID was provided" : "Falsche Datei-ID wurde angegeben",
    "the file was removed" : "die Datei wurde entfernt",
    "the file is corrupt" : "die Datei ist beschädigt",
    "the encryption key is missing" : "Der Verschlüsselungsschlüssel fehlt",
    "Here is the error message returned by the server: " : "Hier ist die Fehlermeldung, welche vom Server zurückgegeben wurde:",
    "For more information, please contact your friendly ownCloud administrator." : "Bitte kontaktiere für mehr Informationen deinen freundlichen ownCloud-Administrator.",
    "Sorry, but the server could not fulfill your request." : "Entschuldigung, aber der Server konnte deine Anfrage nicht beantworten.",
    "Possible reasons for the problem:" : "Mögliche Gründe für das Problem:",
    "a conflicting app was installed" : "eine konfliktträchtige App wurde installiert",
    "a required component is missing or was disconnected" : "Eine Komponente, welche vonnöten ist, fehlt oder wurde getrennt",
    "the filesystem is not readable" : "Das Dateisystem ist nicht lesbar",
    "Sorry, this link doesn't seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "the item was removed" : "Das Element wurde entfernt",
    "the link has expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more information, please ask the person who has sent you this link." : "Um nähere Informationen zu erhalten, wende Dich bitte an die Person, die Dir diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Deiner ownCloud hinzufügen",
    "Picture view" : "Bildansicht"
},
"nplurals=2; plural=(n != 1);");
